from sys import argv
import casadi as cs
import alpaqa.casadi_generator as cg

if len(argv) < 2:
    print(f"Usage:    {argv[0]} <name>")
    exit(0)

x = cs.SX.sym("x")
y = cs.SX.sym("y")
unknowns = cs.vertcat(x, y)

p = cs.SX.sym("p")

# Formulate the NLP
# (https://web.archive.org/web/20201111225115/https://web.casadi.org/blog/opti/)
f = (1 - x)**2 + (y - x**2)**2
g = x**2 + p * y**2

C = [0, 0], [5, 5]
D = [0], [1]
param = [2]

cgen = cg.generate_casadi_problem(
    cs.Function("f", [unknowns, p], [f]),
    cs.Function("g", [unknowns, p], [g]),
    second_order="full",
    name=argv[1],
)
cgen.generate()
cg.write_casadi_problem_data(argv[1], C, D, param, [], 0)



import os
import typing


def _is_truthy(s: typing.Optional[str]):
    if s is None:
        return False
    return not s.lower() in ("", "false", "no", "off", "0")


if not typing.TYPE_CHECKING and _is_truthy(os.getenv("ALPAQA_PYTHON_DEBUG")):
    from . import _alpaqa_d
    from ._alpaqa_d import *
    from ._alpaqa_d.float64 import *
    from ._alpaqa_d import __version__ as __c_version__
else:
    from . import _alpaqa
    from ._alpaqa import *
    from ._alpaqa.float64 import *
    from ._alpaqa import __version__ as __c_version__

del _is_truthy, typing, os
